<h1>MyCDP 🌐 <a href="https://pypi.python.org/pypi/mycdp" target="_blank"><img src="https://img.shields.io/pypi/v/mycdp.svg?color=3399EE" alt="PyPI version" /></a></h1>

### **[MyCDP](https://github.com/mdmintz/MyCDP)** (PyPI: [``mycdp``](https://pypi.python.org/pypi/mycdp)) is a collection of autogenerated CDP (Chrome DevTools Protocol) utilities for enabling Chromium automation with Python without the need for external automation drivers (such as WebDriver) for controlling the browser.

Additionally, MyCDP can be used to connect to an existing Chromium browser instance if the `remote-debugging-port` is known. This advanced option allows for browsers to be controlled by multiple automation frameworks at the same time.

This isn't a standalone product. Think of MyCDP as the engine for your framework: By itself, the engine is of little use, but when connected to a framework that provides an interface, MyCDP can transform Chromium into a powerhouse.
